@@ -19,7 +19,6 @@
 __author__ = 'api.sgrinberg@gmail.com (Stan Grinberg)'
 
 import os
-import re
 import thread
 import time
 
@@ -32,14 +31,12 @@ from adspygoogle.common.Logger import Logger
 from adspygoogle.dfp import AUTH_TOKEN_SERVICE
 from adspygoogle.dfp import DEFAULT_API_VERSION
 from adspygoogle.dfp import DfpSanityCheck
-from adspygoogle.dfp import LIB_SHORT_NAME
 from adspygoogle.dfp import LIB_SIG
 from adspygoogle.dfp import REQUIRED_SOAP_HEADERS
 from adspygoogle.dfp.GenericDfpService import GenericDfpService
 
 
 class DfpClient(Client):
-
   """Provides entry point to all web services.
 
   Allows instantiation of all DFP API web services.
@@ -154,16 +151,6 @@ class DfpClient(Client):
       self._headers['authToken'] = None
       self._config['auth_token_epoch'] = 0
 
-    # Insert library's signature into application name.
-    if self._headers['applicationName'].rfind(LIB_SIG) == -1:
-      # Make sure library name shows up only once.
-      if self._headers['applicationName'].rfind(LIB_SHORT_NAME) > -1:
-        pattern = re.compile('.*' + LIB_SHORT_NAME + '.*?\|')
-        self._headers['applicationName'] = pattern.sub(
-            '', self._headers['applicationName'], 1)
-      self._headers['applicationName'] = (
-          '%s%s' % (self._headers['applicationName'], LIB_SIG))
-
     # Initialize logger.
     self.__logger = Logger(LIB_SIG, self._config['log_home'])
 
@@ -212,6 +199,7 @@ class DfpClient(Client):
         config[key] = default_config[key]
     return config
 
+
   def CallRawMethod(self, soap_message, url, server, http_proxy):
     """Call API method directly, using raw SOAP message.
 
